@@ -45,7 +45,7 @@ class LPstatEventhdlr(Eventhdlr):
         pb = self.model.getPrimalbound()
         if pb >= self.model.infinity():
             pb = None
-        
+
         nodedict = {
             "number": node.getNumber(),
             "LPsol": LPsol,
@@ -61,6 +61,7 @@ class LPstatEventhdlr(Eventhdlr):
             "rows": self.model.getNLPRows(),
             "primalbound": pb,
             "dualbound": self.model.getDualbound(),
+            "time": self.model.getSolvingTime()
         }
         # skip 0-iterations LPs (duplicates?)
         if firstlp:
@@ -124,9 +125,11 @@ class TreeD:
         self.verbose = kwargs.get("verbose", True)
         self.color = "age"
         self.colorscale = "Portland"
-        self.colorbar = False
-        self.title = True
-        self.showlegend = True
+        self.colorbar = kwargs.get("colorbar", True)
+        self.title = kwargs.get("title", True)
+        self.showlegend = kwargs.get("showlegend", True)
+        self.showbuttons = kwargs.get("showbuttons", True)
+        self.showslider = kwargs.get("showslider", True)
         self.fontsize = None
         self.nodesize = 5
         self.weights = "knn"
@@ -138,6 +141,7 @@ class TreeD:
         self.include_plotlyjs = "cdn"
         self.nxgraph = nx.Graph()
         self.stress = None
+        self.start_frame = kwargs.get("start_frame", 1)
 
     def transform(self):
         """compute transformations of LP solutions into 2-dimensional space"""
@@ -162,22 +166,25 @@ class TreeD:
         if self.verbose:
             print(f"✔, time: {time()-start:.2f} seconds")
 
-        # self.stress = mf.stress_  # not available with all transformations
+        try:
+            self.stress = mf.stress_  # not available with all transformations
+        except:
+            print("no stress information available for {self.transformation} transformation")
 
         self.df["x"] = xy[:, 0]
         self.df["y"] = xy[:, 1]
 
-    def performSpatialAnalysis(self):
-        """compute spatial correlation between LP solutions and their condition numbers"""
-        import pysal
+    # def performSpatialAnalysis(self):
+    #     """compute spatial correlation between LP solutions and their condition numbers"""
+    #     import pysal
 
-        df = pd.DataFrame(self.nodelist, columns=["LPsol", "condition"])
-        lpsols = df["LPsol"].apply(pd.Series).fillna(value=0)
-        if self.weights == "kernel":
-            weights = pysal.Kernel(lpsols, function=self.kernelfunction)
-        else:
-            weights = pysal.knnW_from_array(lpsols, k=self.knn_k)
-        self.moran = pysal.Moran(df["condition"].tolist(), weights)
+    #     df = pd.DataFrame(self.nodelist, columns=["LPsol", "condition"])
+    #     lpsols = df["LPsol"].apply(pd.Series).fillna(value=0)
+    #     if self.weights == "kernel":
+    #         weights = pysal.Kernel(lpsols, function=self.kernelfunction)
+    #     else:
+    #         weights = pysal.knnW_from_array(lpsols, k=self.knn_k)
+    #     self.moran = pysal.Moran(df["condition"].tolist(), weights)
 
     def _generateEdges(self, separate_frames=False):
         """Generate edge information corresponding to parent information in df
@@ -241,7 +248,7 @@ class TreeD:
             size=self.nodesize,
             color=self.df["age"],
             colorscale=self.colorscale,
-            colorbar=colorbar,
+            colorbar=colorbar if self.colorbar else None,
         )
         node_object = go.Scatter3d(
             x=self.df["x"],
@@ -285,11 +292,7 @@ class TreeD:
             active=0,
             yanchor="top",
             xanchor="left",
-            currentvalue={
-                "prefix": "Age:",
-                "visible": True,
-                "xanchor": "right",
-            },
+            currentvalue={"prefix": "Age:", "visible": True, "xanchor": "right",},
             len=0.9,
             x=0.05,
             y=0.1,
@@ -340,7 +343,9 @@ class TreeD:
                 opacity=0.5,
             )
 
-            frames.append(go.Frame(data=[node_object, primalbound, dualbound], name=str(a)))
+            frames.append(
+                go.Frame(data=[node_object, primalbound, dualbound], name=str(a))
+            )
 
             slider_step = {
                 "args": [
@@ -370,14 +375,10 @@ class TreeD:
 
         frames = []
         sliders_dict = dict(
-            active=0,
+            active=self.start_frame-1,
             yanchor="top",
             xanchor="left",
-            currentvalue={
-                "prefix": "Age:",
-                "visible": True,
-                "xanchor": "right",
-            },
+            currentvalue={"prefix": "Age:", "visible": True, "xanchor": "right",},
             len=0.9,
             x=0.05,
             y=0.1,
@@ -524,27 +525,28 @@ class TreeD:
                     buttons=list(
                         [
                             dict(
-                                label="|▶",
+                                label="▶",
                                 method="animate",
                                 args=[
                                     None,
                                     {
-                                        "frame": {
-                                            "duration": 50,
-                                            "redraw": True,
-                                        },
+                                        "frame": {"duration": 50, "redraw": True,},
                                         "fromcurrent": True,
                                     },
                                 ],
-                                args2=[
+                            ),
+                            dict(
+                                label="◼",
+                                method="animate",
+                                args=[
                                     [None],
                                     {
-                                        "frame": {"duration": 1, "redraw": False},
+                                        "frame": {"duration": 0, "redraw": False},
                                         "mode": "immediate",
-                                        "transition": {"duration": 1},
+                                        "transition": {"duration": 0},
                                     },
                                 ],
-                            )
+                            ),
                         ]
                     ),
                     direction="left",
@@ -637,9 +639,10 @@ class TreeD:
             title = f"TreeD: {self.probname} ({self.scipversion}, {self.status})"
         else:
             title = ""
-        
+
         filename = "TreeD_" + self.probname + ".html"
 
+        camera = dict(eye=dict(x=1.5, y=1.3, z=0.5))
         layout = go.Layout(
             title=title,
             font=dict(size=self.fontsize),
@@ -650,12 +653,15 @@ class TreeD:
             showlegend=self.showlegend,
             hovermode="closest",
             scene=scene,
+            scene_camera=camera,
             template="none",
         )
 
-        layout["updatemenus"] = self.updatemenus()
-        layout["sliders"] = [sliders]
-
+        if self.showbuttons:
+            layout["updatemenus"] = self.updatemenus()
+        if self.showslider:
+            layout["sliders"] = [sliders]
+        
         self.fig = go.Figure(
             data=[nodes, primalbound, dualbound, optval, nodeprojs, edges],
             layout=layout,
@@ -680,9 +686,11 @@ class TreeD:
         self.hierarchy_pos()
         frames, sliders = self._create_nodes_frames_2d()
 
+        start_frame = self.df[self.df["age"] <= self.start_frame]
+
         Xv = [self.pos2d[k][0] for k in self.df["id"]]
         # Yv = [self.pos2d[k][1] for k in self.df["id"]]
-        Yv = self.df["objval"]
+        # Yv = self.df["objval"]
         Xed = []
         Yed = []
         for edge in self.nxgraph.edges:
@@ -696,7 +704,7 @@ class TreeD:
             size=self.nodesize * 2,
             color=self.df["age"],
             colorscale=self.colorscale,
-            colorbar=colorbar,
+            colorbar=colorbar if self.colorbar else None,
         )
 
         edges = go.Scatter(
@@ -708,8 +716,8 @@ class TreeD:
             name="Edges",
         )
         nodes = go.Scatter(
-            x=Xv,
-            y=Yv,
+            x=[self.pos2d[k][0] for k in start_frame["id"]],
+            y=start_frame["objval"],
             name="LP solutions",
             mode="markers",
             marker=marker,
@@ -729,14 +737,14 @@ class TreeD:
         xmax = max(Xv)
         primalbound = go.Scatter(
             x=[xmin, xmax],
-            y=2 * [self.df["primalbound"].iloc[len(self.df) - 1]],
+            y=2 * [start_frame["primalbound"].iloc[-1]],
             mode="lines",
             opacity=0.5,
             name="Primal Bound",
         )
         dualbound = go.Scatter(
             x=[xmin, xmax],
-            y=2 * [self.df["dualbound"].iloc[len(self.df) - 1]],
+            y=2 * [start_frame["dualbound"].iloc[-1]],
             mode="lines",
             opacity=0.5,
             name="Dual Bound",
@@ -749,9 +757,16 @@ class TreeD:
             name="Optimum",
         )
 
-        margin = 0.05*xmax
-        xaxis = go.layout.XAxis(title="", visible=False, range=[xmin-margin, xmax+margin], autorange=False)
-        yaxis = go.layout.YAxis(title="Objective value", visible=True, side="right", position=0.98)
+        margin = 0.05 * xmax
+        xaxis = go.layout.XAxis(
+            title="",
+            visible=False,
+            range=[xmin - margin, xmax + margin],
+            autorange=False,
+        )
+        yaxis = go.layout.YAxis(
+            title="Objective value", visible=True, side="right", position=0.98
+        )
 
         if self.title:
             title = f"Tree 2D: {self.probname} ({self.scipversion}, {self.status})"
@@ -771,7 +786,8 @@ class TreeD:
             yaxis=yaxis,
         )
 
-        layout["updatemenus"] = self.updatemenus()
+        if self.showbuttons:
+            layout["updatemenus"] = self.updatemenus()
         layout["sliders"] = [sliders]
 
         self.fig2d = go.Figure(
@@ -910,19 +926,23 @@ class TreeD:
         if self.df is None:
             return
 
-        self.origdist = []
-        self.transdist = []
+        origdist = []
+        transdist = []
         for i in range(len(self.df)):
             for j in range(i + 1, len(self.df)):
-                self.origdist.append(
+                origdist.append(
                     self.distance(self.df["LPsol"].iloc[i], self.df["LPsol"].iloc[j])
                 )
-                self.transdist.append(
+                transdist.append(
                     self.distance(
                         self.df[["x", "y"]].iloc[i], self.df[["x", "y"]].iloc[j]
                     )
                 )
+        self.distances = pd.DataFrame()
+        self.distances["original"] = origdist
+        self.distances["transformed"] = transdist
 
+    @staticmethod
     def distance(p1, p2):
         """euclidean distance between two coordinates (dict-like storage)"""
         dist = 0
